Add-PsSnapin Microsoft.SharePoint.PowerShell

#Do not modify anything in the script from here onwards
function Get-ScriptDirectory
{
 $Invocation = (Get-Variable MyInvocation -Scope 1).Value
 Split-Path $Invocation.MyCommand.Path
}

function Deploy-Solution{
param(
[string]$physicalPath,
[string]$name)

$SolutionName = $name
$SolutionPath = Join-Path ($physicalPath) $SolutionName


#Admin service
$AdminServiceName = "SPAdminV4"
$IsAdminServiceWasRunning = $true;

if ($(Get-Service $AdminServiceName).Status -eq "Stopped")
{
    $IsAdminServiceWasRunning = $false;
    Start-Service $AdminServiceName
   Write-Host 'SharePoint Administration service is started.'
   Write-Host ''
}

#Timer service
$TimerServiceName = "SPTimerV4"
$IsTimerServiceRunning = $true;


if ($(Get-Service $TimerServiceName).Status -eq "Stopped")
{
    $IsTimerServiceRunning = $false;
    Start-Service $TimerServiceName
   Write-Host 'SharePoint Timer service is started.'
   Write-Host ''
}

#Uninstall


$Solution = Get-SPSolution | ? {($_.Name -eq $SolutionName) -and ($_.Deployed -eq $true)}

if ($Solution -ne $null)
{
    Write-Host 'Uninstalling'$SolutionName
    if($Solution.ContainsWebApplicationResource)
    {
        Uninstall-SPSolution $SolutionName -AllWebApplications -Confirm:$false
    }
    else
    {
        Uninstall-SPSolution $SolutionName -Confirm:$false
    }
    while ($Solution.JobExists)
    {
        Start-Sleep 2
    }

    Write-Host $SolutionName 'has been uninstalled.'

    Write-Host 'Removing'$SolutionName
}



if ($(Get-SPSolution | ? {$_.Name -eq $SolutionName}).Deployed -eq $false)
{
    Remove-SPSolution $SolutionName -Confirm:$false

    Write-Host $SolutionName 'has been removed.'
    Write-Host ''
}

Write-Host 'Adding' $SolutionName

Add-SPSolution $SolutionPath  | Out-Null

Write-Host $SolutionName 'has been added'

Write-Host 'Deploying'$SolutionName

$Solution = Get-SPSolution | ? {($_.Name -eq $SolutionName) -and ($_.Deployed -eq $false)}

#use '-force' paramater to install all commands in this if statement

if(($Solution -ne $null) -and ($Solution.ContainsWebApplicationResource))
{
Install-SPSolution $SolutionName AllwebApplications -GACDeployment -Force -Confirm:$false
}
else
{
Install-SPSolution $SolutionName -GACDeployment -Force -Confirm:$false
}

while ($Solution.Deployed -eq $false)
{
    Start-Sleep 2
}

Write-Host $SolutionName 'has been deployed.'
Write-Host ''

if (-not $IsAdminServiceWasRunning)
{
    Stop-Service $AdminServiceName
}
}

#Get Current Physical Path
$currentPhysicalPath = Get-ScriptDirectory

#Iterate through all .wsp files in the current Physical Path to deploy solution
Deploy-Solution $currentPhysicalPath "SPInformationOrganizerService.wsp"
Deploy-Solution $currentPhysicalPath "SPInformationOrganizer.wsp"


#Remove SharePoint Snapin
Remove-PsSnapin Microsoft.SharePoint.PowerShell

Echo Finish
